Top

    Gothcon
    Goteborg, Sweden
    March 26th 2016
    3R+F
    16 players
    Hugh Angseesing

    Deck Name : DoC Swedish Sirens
    Description : 2GW9 and winner in Sweden qualifier 26th March 2016

    Crypt (12 cards, min=15, max=24, avg=5.08)
    ------------------------------------------
    2x Jost Werner			  6   AUS PRE ani	Toreador antitribu:2
    2x Sheila Mezarin		  6   AUS PRE cel for	Toreador antitribu:2
    2x Angela Preston		  5   MEL PRE for	Daughter of Cacophony:2
    1x Gaël Pilet			  6   FOR MEL chi pre	Daughter of Cacophony:2
    1x Yseult			  6   FOR MEL PRE	Daughter of Cacophony:3
    1x Delilah Monroe		  4   MEL for pre	Daughter of Cacophony:2
    1x Maldavis			  4   AUS for pre	Caitiff:3
    1x Remilliard, Devout Crusader	  4   AUS pre		Toreador antitribu:2
    1x Céleste, The Voice of a Secret 3   mel pre		Daughter of Cacophony:2

    Library (88 cards)
    Master (19; 4 trifle)
    3x Anarch Troublemaker
    1x Archon Investigation
    2x Blood Doll
    1x Coven, The
    1x Direct Intervention
    1x Dreams of the Sphinx
    1x Fetish Club Hunting Ground
    1x Giant's Blood
    1x Palla Grande
    1x Paris Opera House
    1x Pentex(TM) Subversion
    2x Presence
    3x Vessel

    Action (13)
    4x Entrancement
    4x Legal Manipulations
    2x Mind Numb
    3x Social Charm

    Action Modifier (21)
    6x Aire of Elation
    2x Daring the Dawn
    4x Missing Voice, The
    2x Phantom Speaker
    7x Siren's Lure

    Reaction (20)
    3x Delaying Tactics
    2x My Enemy's Enemy
    2x On the Qui Vive
    8x Telepathic Misdirection
    5x Wake with Evening's Freshness

    Combat (14)
    8x Majesty
    6x Soak

    Event (1)
    1x Uncoiling, The